@@ -6,13 +6,12 @@
 #' @param case.location Character. "address" or "nominal". "address" is the x-y coordinates of \code{sim.ortho.proj}. "nominal" is the x-y coordinates of \code{regular.cases}.
 #' @param type Character. Type of plot: "star", "area.points" or "area.polygons".
 #' @param alpha.level Numeric. Alpha level transparency for area plot: a value in [0, 1].
-#' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. You can also specify the number logical cores. On Windows, only \code{multi.core = FALSE} is available.
+#' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. You can also specify the number logical cores. See \code{vignette("Parallelization")} for details.
+#' @param dev.mode Logical. Development mode uses parallel::parLapply().
 #' @return R graphic elements.
-#' @note This function is computationally intensive. On a single core of a 2.3 GHz Intel i7, plotting observed paths to PDF takes about 3.6 seconds while doing so for expected paths takes about 109 seconds. Using the parallel implementation on 4 physical (8 logical) cores, these times fall to about 1.4 and 28 seconds. Note that parallelization is currently only available on Linux and Mac, and that although some precautions are taken in R.app on macOS, the developers of the 'parallel' package, which \code{neighborhoodWalking()} uses, strongly discourage against using parallelization within a GUI or embedded environment. See \code{vignette("parallel")} for details. Also, the function computes approximate of polygons, using the 'TSP' package, that may produce non-simple and/or overlapping polygons.
 #' @export
 #' @examples
 #' \donttest{
-#'
 #' streetNameLocator("marshall street", zoom = 0.5, highlight = FALSE,
 #'   add.subtitle = FALSE)
 #' addNeighborhoodEuclidean()
@@ -24,7 +23,7 @@
 
 addNeighborhoodEuclidean <- function(pump.subset = NULL, pump.select = NULL,
   vestry = FALSE, case.location = "nominal", type = "star", alpha.level = 0.5,
-  multi.core = FALSE) {
+  multi.core = FALSE, dev.mode = FALSE) {
 
   if (case.location %in% c("address", "nominal") == FALSE) {
     stop('case.location must be "address" or "nominal".')
@@ -64,10 +63,21 @@ addNeighborhoodEuclidean <- function(pump.subset = NULL, pump.select = NULL,
 
   anchors <- seq_len(nrow(cholera::regular.cases))
 
-  nearest.pump <- parallel::mclapply(anchors, function(x) {
-    euclideanPath(x, destination = pump.id, vestry = vestry,
-      observed = FALSE, case.location = case.location)$data$pump
-  }, mc.cores = cores)
+  if ((.Platform$OS.type == "windows" & cores > 1) | dev.mode) {
+    cl <- parallel::makeCluster(cores)
+    parallel::clusterExport(cl = cl, envir = environment(),
+      varlist = c("pump.id", "vestry", "case.location"))
+    nearest.pump <- parallel::parLapply(cl, anchors, function(x) {
+      cholera::euclideanPath(x, destination = pump.id, vestry = vestry,
+        observed = FALSE, case.location = case.location)$data$pump
+    })
+    parallel::stopCluster(cl)
+  } else {
+    nearest.pump <- parallel::mclapply(anchors, function(x) {
+      euclideanPath(x, destination = pump.id, vestry = vestry,
+        observed = FALSE, case.location = case.location)$data$pump
+    }, mc.cores = cores)
+  }
 
   if (is.null(pump.subset)) {
     x <- list(pump.data = pump.data,
@@ -139,10 +149,8 @@ addNeighborhoodEuclidean <- function(pump.subset = NULL, pump.select = NULL,
       which(nearest.pump == n)
     })
 
-    periphery.cases <- parallel::mclapply(neighborhood.cases, peripheryCases,
-      mc.cores = x$cores)
-    pearl.string <- parallel::mclapply(periphery.cases, travelingSalesman,
-      mc.cores = x$cores)
+    periphery.cases <- lapply(neighborhood.cases, peripheryCases)
+    pearl.string <- lapply(periphery.cases, travelingSalesman)
     names(pearl.string) <- p.num
 
     invisible(lapply(names(pearl.string), function(nm) {
