@@ -6,24 +6,19 @@ pearlStringRadius <- function() {
   c(stats::dist(cholera::regular.cases[c(1, 2), ]))
 }
 
-# remove observations with neighbors at each of the 4 cardinal directions
 peripheryCases <- function(n.points, radius = pearlStringRadius()) {
   n.area <- cholera::regular.cases[n.points, ]
+
   periphery.test <- vapply(seq_len(nrow(n.area)), function(i) {
     case.point <- n.area[i, ]
-
     N <- signif(case.point$x) == signif(n.area$x) &
          signif(case.point$y + radius) == signif(n.area$y)
-
     E <- signif(case.point$x + radius) == signif(n.area$x) &
          signif(case.point$y) == signif(n.area$y)
-
     S <- signif(case.point$x) == signif(n.area$x) &
          signif(case.point$y - radius) == signif(n.area$y)
-
     W <- signif(case.point$x - radius) == signif(n.area$x) &
          signif(case.point$y) == signif(n.area$y)
-
     sum(c(N, E, S, W)) == 4
   }, logical(1L))
 
@@ -34,7 +29,6 @@ peripheryCases <- function(n.points, radius = pearlStringRadius()) {
 #'
 #' @param vertices Object. Polygon vertices candidates.
 #' @param tsp.method Character. Traveling saleman algorithm. See TSP::solve_TSP() for details. Default method is repetitive nearest neighbor: "repetitive_nn".
-#' @note Default method for neighborhoodEuclidean().
 #' @noRd
 
 travelingSalesman <- function(vertices, tsp.method = "repetitive_nn") {
@@ -58,6 +52,8 @@ travelingSalesman <- function(vertices, tsp.method = "repetitive_nn") {
   names(soln)
 }
 
+index0 <- function(x) as.data.frame(t(utils::combn(length(x), 2)))
+
 ## diagnostic plots ##
 
 #' Plot periphery cases.
@@ -74,7 +70,6 @@ peripheryAudit <- function(x, i = 1, pch = 16, cex = 0.5) {
   neighborhood.cases <- lapply(p.num, function(n) {
     which(nearest.pump == n)
   })
-
   periphery.cases <- parallel::mclapply(neighborhood.cases, peripheryCases,
     mc.cores = x$cores)
   points(cholera::regular.cases[periphery.cases[[i]], ], pch = pch, cex = cex,
@@ -93,7 +88,6 @@ polygonAudit <- function(x, i = 1) {
   neighborhood.cases <- lapply(p.num, function(n) {
     which(nearest.pump == n)
   })
-
   periphery.cases <- parallel::mclapply(neighborhood.cases, peripheryCases,
     mc.cores = x$cores)
   pearl.string <- parallel::mclapply(periphery.cases, travelingSalesman,
