@@ -5,7 +5,6 @@
 #' @export
 #' @examples
 #' \donttest{
-#'
 #' pearsonResiduals(neighborhoodEuclidean())
 #' pearsonResiduals(neighborhoodVoronoi())
 #' pearsonResiduals(neighborhoodWalking())
@@ -79,7 +78,7 @@ pearson <- function(x) {
 #' @noRd
 
 expectedWalkingLength <- function(x) {
-  dat <- observedExpected(x)
+  dat <- observedExpected(x, neighborhoodPathData(x))
   observed.wholes <- dat$observed.wholes
   expected.wholes <- dat$expected.wholes
   obs.splits <- dat$exp.splits
