@@ -3,11 +3,10 @@
 #' Returns either the set of x-y coordinates for the pumps themselves or for their orthogonally projected "addresses" on the network of roads.
 #' @param vestry Logical. \code{TRUE} uses the 14 pumps from the Vestry report. \code{FALSE} uses the 13 in the original map.
 #' @param orthogonal Logical. \code{TRUE} returns pump "addresses": the coordinates of the orthogonal projection from a pump's location onto the network of roads. \code{FALSE} returns pump location coordinates.
-#' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. With Numeric, you specify the number logical cores (rounds with \code{as.integer()}). On Windows, only \code{multi.core = FALSE} is available.
-#' @note Note: The location of the fourteenth pump, at Hanover Square, and the "correct" location of the Broad Street pump are approximate.
+#' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. With Numeric, you specify the number logical cores (rounds with \code{as.integer()}). See \code{vignette("Parallelization")} for details.
 #' @seealso\code{\link{pumpLocator}}
 #' @return An R data frame.
-#' @note The Dodson and Tobler coordinates of the original thirteen pumps, appended with name of nearest road, or the fourteen pumps included in the second version of Snow's map included in the Vestry report. This function documents the code that generates \code{\link{pumps}}, \code{\link{pumps.vestry}}, \code{\link{ortho.proj.pump}} and \code{\link{ortho.proj.pump.vestry}}.
+#' @note Note: The location of the fourteenth pump, at Hanover Square, and the "correct" location of the Broad Street pump are approximate. This function documents the code that generates \code{\link{pumps}}, \code{\link{pumps.vestry}}, \code{\link{ortho.proj.pump}} and \code{\link{ortho.proj.pump.vestry}}.
 #' @export
 
 pumpData <- function(vestry = FALSE, orthogonal = FALSE, multi.core = FALSE) {
@@ -62,8 +61,8 @@ pumpData <- function(vestry = FALSE, orthogonal = FALSE, multi.core = FALSE) {
 
       within.radius <- lapply(road.segments$id, function(x) {
         seg.data <- cholera::road.segments[cholera::road.segments$id == x, ]
-        test1 <- withinRadius(case, seg.data[, c("x1", "y1")])
-        test2 <- withinRadius(case, seg.data[, c("x2", "y2")])
+        test1 <- cholera::withinRadius(case, seg.data[, c("x1", "y1")])
+        test2 <- cholera::withinRadius(case, seg.data[, c("x2", "y2")])
         if (any(test1, test2)) unique(seg.data$id)
       })
 
